
======
ggwave
======

Tiny data-over-sound library.

Possible applications:

- Serverless, one-to-many broadcast
- Device pairing
- Authorization
- Internet of Things
- Audio QR codes


.. code:: python

    ggwave.ggwaveTest()
    # 0


ggwave is actually a C/C++ library, and this package is it's wrapper for Python.

--------
Features
--------

* TODO

------------
Installation
------------
::

    pip install ggwave

---
API
---

TODO

----
More
----

Check out `C/C++ ggwave docs <http://github.com/ggerganov/ggwave>`_ for more information about ggwave!

-----------
Development
-----------

Check out `ggwave python package on Github <https://github.com/ggerganov/ggwave/tree/master/bindings/python>`_.
